from cqh_file_watcher.run import main


if __name__ == "__main__":
    main()
